package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````8"(```````!``````````#"Q````
M`````````$``.``-`$``&P`:``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````#@;````````.!L`````````
M$`````````$````%`````"``````````(``````````@````````33L`````
M``!-.P`````````0`````````0````0`````8`````````!@`````````&``
M``````#@1@```````.!&`````````!`````````!````!@```,"K````````
MP+L```````#`NP```````&`$````````X!0`````````$`````````(````&
M````T*L```````#0NP```````-"[````````(`(````````@`@````````@`
M````````!`````0````X`P```````#@#````````.`,```````!`````````
M`$``````````"``````````$````!````'@#````````>`,```````!X`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````0`````````!```````````@`````````4.5T9`0`
M``!PGP```````'"?````````<)\```````#T`````````/0`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````P*L```````#`NP```````,"[````
M````0`0```````!`!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````,`````4```!'3E4``H``P`0````!````````
M``$``<`$````"0`````````"``'`!`````$`````````!````!0````#````
M1TY5`":?I5GO.>@]64K:_8.8?'+Z:_OV!````!`````!````1TY5```````$
M````!```````````````/0```$`````$````"````"`<$``%0`2&*`)`!)"&
M`(2""0`@22`$"+BB$$6Z``(*``````````!``````````$$```!#````10``
M``````!&`````````$<```!(````20```$L``````````````$P`````````
M````````````````````````````````30```$X```!0````4@``````````
M`````````%,`````````5`````````!5``````````````!6````5P``````
M``!8````60```````````````````%H`````````6P``````````````7```
M`%T```!?``````````````!@`````````````````````````+OCDGRFW:-K
M:QJ>4"[%F[9#^M>'%8PES&>OS&9OQ=\?B0=PT\2)!9"CX/M)^Z%L8-5DU'S#
MY3\L?JF<FZU+X\#B1\8!S]Y'+0T4XIXA_^0.X:<""MO-XYX+BA!7LP&+;PTZ
MEPO9<5@<5Z2;EC-BV^UK"4/6Q+F<0#GRBQQ#1=7L:W^:?```````````````
M`````````````````!H!```2`````````````````````````(H!```2````
M`````````````````````.0!```2`````````````````````````,(!```2
M``````````````````````````$````@`````````````````````````.L!
M```2`````````````````````````&H"```2````````````````````````
M```"```2`````````````````````````)<````2````````````````````
M`````#X"```2`````````````````````````%0"```2````````````````
M`````````-@````2`````````````````````````#T#```2````````````
M`````````````!4!```2`````````````````````````","```2````````
M`````````````````!4"```2`````````````````````````-,!```2````
M`````````````````````&,"```2`````````````````````````#\"```2
M`````````````````````````',"```2`````````````````````````.<`
M```2`````````````````````````+L````2````````````````````````
M`/4````2`````````````````````````+<!```2````````````````````
M`````,H!```2`````````````````````````-,"```2````````````````
M`````````!\!```2`````````````````````````/D!```2````````````
M`````````````(4!```2`````````````````````````+<"```2````````
M`````````````````+`"```2`````````````````````````%,````2````
M`````````````````````!T````@`````````````````````````#<"```2
M`````````````````````````#(!```2`````````````````````````*,!
M```2`````````````````````````"L!```2````````````````````````
M`(`````2```````````````````````````!```2````````````````````
M`````(P````2`````````````````````````%(!```2````````````````
M`````````&4!```2`````````````````````````&,````2````````````
M`````````````$8"```2`````````````````````````+`````2````````
M`````````````````$$!```2`````````````````````````/$!```2````
M`````````````````````'X!```2`````````````````````````*$"```2
M`````````````````````````'H"```2`````````````````````````&\`
M```2`````````````````````````*D"```2````````````````````````
M``X"```2`````````````````````````,D````2````````````````````
M`````*<````2`````````````````````````+T!```2````````````````
M`````````)L!```2`````````````````````````"D"```2````````````
M`````````````"P````@``````````````````````````<"```2````````
M`````````````````(0"```B`````````````````````````!P"```2````
M`````````````````````),"```2`````````````````````````-8#```0
M`!@`H-```````````````````,L"```A`!@`0,`````````(`````````.@#
M```2``X`P%@```````#K`0```````!H#```2``X`\"H````````%````````
M`'\#```2``X`$%<```````"G`0```````#,$```2``X`L%8```````!5````
M`````&8#```2``X`0"T```````#=`````````$8#```2``X`8#\````````'
M`0```````,P#```1`!<`&,`````````(`````````,H"```A`!@`0,``````
M```(`````````-L#```2``X`("X```````"?!````````!,$```2``X`8#,`
M```````0`0```````#P$```2``X`L#P```````"I`@```````/X#```2``X`
MX"D````````R`````````"L#```2``X`0#,````````?`````````)<#```1
M`!```&`````````$`````````%D#```2``X`$"T````````E`````````'(#
M```2``X`<#0````````Q"`````````H#```2``X`(%L````````%````````
M``8$```2``X``"L````````%`@```````*8#```2``X`("H```````#%````
M`````+P#```2``X`L%H```````!E`````````$8````1`!@`,,`````````!
M`````````"4$```2``X`P#(```````!U`````````(P#```@`!<``,``````
M`````````````/(#```0`!@`(,```````````````````',!```1`!@`(,``
M```````$`````````)`#```2``X`8"(````````O`````````(H#```0`!<`
M`,```````````````````,D"```1`!@`0,`````````(`````````%P"```1
M`!@`8,`````````(`````````%(#```0`!<`(,```````````````````,0"
M```2``X`0"`````````6`@````````!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!03%]D;U]U;F1U;7``4&5R;%]G=E]F971C:'!V`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7VQO8VL`4&5R;%]G971?<W8`4&5R;%]N97=84P!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]R=6X`<&5R;%]P87)S90!097)L7W-V7W-E='!V`%!E
M<FQ?<W9?<V5T<'9N`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?9&5S=')U8W0`<&5R
M;%]A;&QO8P!097)L7V-R;V%K7VYO8V]N=&5X=`!P97)L7V9R964`4&5R;%]S
M869E<WES;6%L;&]C`%!E<FQ?<WES7VEN:70S`%!E<FQ?;F5W6%-?9FQA9W,`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<WES7W1E<FT`4$Q?=&AR7VME>0!O
M<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<'1H<F5A9%]G
M971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C
M:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED
M`'-T<F1U<`!S=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?
M8VAK`&UE;6-P>0!L<W1A=#8T`%]?<W1R;F-P>5]C:&L`;W!E;F1I<@!S=&1E
M<G(`9V5T=6ED`')E861L:6YK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN
M86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L
M:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`&QI
M8G!E<FPN<V\`;&EB<'1H<F5A9"YS;RXP`&QI8F,N<V\N-@!?7VQI8F-?8W-U
M7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!?961A=&$`<&%R7V)A<V5N86UE`'!A<E]D:7)N
M86UE`'!A<E]M:W1M<&1I<@!S:&%?=7!D871E`%]?9&%T85]S=&%R=`!?24]?
M<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I
M;FET`&UY7W!A<E]P;`!?96YD`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B
M<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/
M3U0`1TQ)0D-?,BXR+C4`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXQ-`!'3$E"0U\R
M+C,N,@!'3$E"0U\R+C0`1TQ)0D-?,BXS,P`O=7-R+VQI8B]P97)L-2\U+C,T
M+V-O<F5?<&5R;"]#3U)%``````(``P`"``(````"``(``@````0``@````(`
M```"``(`!0`"``0``@`````````#``(`!@````(``P`"``(```````<````#
M``(`````````````````"````````@`#``(``@````(``@```````@`#``@`
M```"``(``@`(``$``@`!``$``0`!``$``0`!``(``0`!``$``0`!``$``0`!
M``$``0`!``$````!``$``0````$``0`"``(``0`!```````!``$`\`(``!``
M```@````=1II"0```P!2!`````````$`!@```P``$`````````!T&6D)```(
M`%X$```0````E)&6!@``!P!J!```$````'(9:0D```8`=00``!`````4:6D-
M```%`($$```0````LY&6!@``!`"+!```$````'4::0D```(`4@0```````#`
MNP````````@`````````4",```````#(NP````````@``````````",`````
M```(P`````````@`````````",`````````8P`````````@`````````X&(`
M```````0O@````````8````!```````````````8O@````````8````"````
M```````````@O@````````8````#```````````````HO@````````8````$
M```````````````PO@````````8````%```````````````XO@````````8`
M```&``````````````!`O@````````8````'``````````````!(O@``````
M``8````(``````````````!0O@````````8````)``````````````!8O@``
M``````8````*``````````````!@O@````````8````+``````````````!H
MO@````````8````,``````````````!PO@````````8````-````````````
M``!XO@````````8````.``````````````"`O@````````8````/````````
M``````"(O@````````8````0``````````````"0O@````````8````1````
M``````````"8O@````````8````2``````````````"@O@````````8````3
M``````````````"HO@````````8````4``````````````"PO@````````8`
M```5``````````````"XO@````````8````6``````````````#`O@``````
M``8````7``````````````#(O@````````8````8``````````````#0O@``
M``````8````9``````````````#8O@````````8````;``````````````#@
MO@````````8````<``````````````#HO@````````8````=````````````
M``#PO@````````8````>``````````````#XO@````````8````?````````
M````````OP````````8````@```````````````(OP````````8````A````
M```````````0OP````````8````B```````````````8OP````````8````C
M```````````````@OP````````8````D```````````````HOP````````8`
M```E```````````````POP````````8````F```````````````XOP``````
M``8````G``````````````!`OP````````8````H``````````````!(OP``
M``````8````I``````````````!0OP````````8````J``````````````!8
MOP````````8````K``````````````!@OP````````8````L````````````
M``!HOP````````8````M``````````````!POP````````8````N````````
M``````!XOP````````8````O``````````````"`OP````````8````P````
M``````````"(OP````````8````Q``````````````"0OP````````8````R
M``````````````"8OP````````8````S``````````````"@OP````````8`
M```T``````````````"HOP````````8````U``````````````"POP``````
M``8````V``````````````"XOP````````8````W``````````````#`OP``
M``````8````X``````````````#(OP````````8````Y``````````````#0
MOP````````8````Z``````````````#8OP````````8````[````````````
M``#@OP````````8````\``````````````#HOP````````8````]````````
M``````#POP````````8````^``````````````#XOP````````8````_````
M```````````@P`````````4```!:```````````````PP`````````4```!6
M``````````````!`P`````````4```!=``````````````!@P`````````4`
M``!>```````````````(O@````````<````:````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!?F>``!(A<!T`O_02(/$",,``````/\UTIT``/\EU)T`
M``\?0`#_)=*=``!H`````.G@____05152(/L.(E\)!Q(C7PD'$B)="002(UT
M)!!(B50D"$B-5"0(9$B+!"4H````2(E$)"@QP/\5GIX``$B+-<>>``!(BST0
MGP``2(GR9^B?.@``@#V8GP```'4R_Q4@G@``2(D%\:\``$B)QTB%P`^$D@$`
M`/\5KYT``(L]89\``/\56YX``,:`UPD```"+/4Z?``#_%4B>``"+/4*?``"`
MB"H$```"_Q4UG@``@(@J!````8M$)!R->`1$C6`#2&/_2,'G`_\5SIT``$B+
M?"002(G!2(D%=Z\``$B+!TB)`4B-!:A```!(B4$(2(L%YYX``$B)01!(C065
M0```2(E!&(M$)!R#^`$/CNX```!(@\<(@\`#N@0````/'X``````3(L'2&/R
M@\(!2(/'"$R)!/$YT'7K2)A$B>)(BST7KP``13'`2,<$P0````!(C37=!P``
M_Q7/G0``08G$A<!T5DB-;"0D2(L][*X``/\5_IP``#'`2(GN2(T]Y3X``.B=
M`0``2(7`=$!(BSW)K@``_Q6CG```_Q5UG0``2(M$)"AD2"L$)2@```!U94B#
MQ#A$B>!=05S#2(L]FZX``/\5M9T``$&)Q.N82(L]>:X``$B%_W0'Z$<=``#K
MK4B-/38^``!(B>[H-@$``$B)!5>N``!(B<=(A<!TC^O9N`0```#I,/___[\!
M````_Q5PG0``_Q4ZG```9BX/'X0``````/,/'OHQ[4F)T5Y(B>)(@^3P4%1,
MC06F.```2(T-+S@``$B-/;C]____%6*<``#TD$B-/8F=``!(C06"G0``2#GX
M=!5(BP6&FP``2(7`=`G_X`\?@`````###Q^``````$B-/5F=``!(C352G0``
M2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!>V<``!(A<!T"/_@9@\?1```PP\?
M@`````#S#Q[Z@#U=G0```'4S54B#/=*<````2(GE=`U(BSWFG```_Q7`G```
MZ&/____&!32=```!7<-F+@\?A```````PV9F+@\?A```````#Q]``/,/'OKI
M9____P\?@`````!!5T%6055!5%532(/L"$B%_P^$L0```$R++<*<``!-A>T/
MA*$````/M@=)B?](B?6$P'0$/#UU6$4Q]DV+90!-A>1T,TUC]DR)ZV8/'T0`
M`$R)\DR)_DR)Y_\5:9H``(7`=0=#@#PT/71&3(MC"$B#PPA-A>1UV4B#Q`A,
MB>!;74%<05U!7D%?PP\?@`````!)B?Y!#[9&`4F#Q@&$P'0$/#UU[T4I_NN2
M#Q^``````$PIZT^-9#0!2,'[`XE=`.NV#Q^``````$4QY.NJ#Q\`059!54%4
M55-(@>R@````9$B+!"4H````2(F$))@````QP$B%_W0(@#\`2(G]=3%(BX0D
MF````&1(*P0E*`````^%,0$``$B!Q*````!;74%<05U!7L-F+@\?A```````
M_Q7*F0``3(TM9SL``$F)Q$B%P'2Z3(GG_Q7BF@``2(7`#X2Q````@'@3+DB-
M6!-U#X![`0!TWF8/'X0``````(!X$RX/A*8```!(B>__%:69``!(B=])B<;_
M%9F9``!!C7P&`DAC__\5*YH``$F)V4F)Z$R)Z4F)QDB)Q[X!````,<!(Q\+_
M_____Q78F@``3(GW2(GF_Q5TF0``3(GW@_C_=!"+1"08)0#P```]`$```'1<
M_Q76F```3(GW_Q6]F```3(GG_Q4TF@``2(7`#X52____#Q\`3(GG_Q5?F0``
M2(GO_Q4&F0``Z>#^__^0@'L!+@^%4/___X![`@`/A!'____I0?___P\?@```
M``#HB_[__^NC_Q7CF```#Q\`54B)_4B![*````!D2(L$)2@```!(B80DF```
M`#'`2(GF_Q6!F```A<!U-8M4)!B!X@#P``"!^@!```!T"('Z`*```'4=O@(`
M``!(B>__%9V9``"%P`^4P`^VP.L%#Q\`,<!(BY0DF````&1(*Q0E*````'4)
M2('$H````%W#_Q5<F```9F8N#Q^$``````"005:Z_P\``$%5051)B?152(G]
M2(T]L3D``$B![!@0``!D2(L$)2@```!(B80D"!```#'`28GE3(GN_Q7!EP``
MA<!^38U0_TQC\D*`/#0`#X5\````A=)T.$R)\KXO````3(GO_Q4WF```2(7`
M="*+/6R9``#_%6:8``!,B?%,B>I(B>Y(B<?_%>28``#K'6:0BSU*F0``_Q5$
MF```3(GB2(GN2(G'_Q7-EP``2(N$)`@0``!D2"L$)2@```!U&DB!Q!@0``!=
M05Q!74%>PP\?`$QC\.F`_____Q5REP``9I!!5T%6055!5%5(B?532(G[2(/L
M&&1(BP0E*````$B)1"0(,<`QP(`^/0^4P$@!Q4B)[_\5,)<``$B-="0$2(G?
M28G$,<#H]OO__TB%P`^$#0$``$F)Q4B)Q_\5"9<``$DYQ`^&V````$QC="0$
M2<'F`P^V`X3`#X2L`0``/#T/A*0!``!(B=AF#Q^$```````/ME`!2(/``832
M=`6`^CUU[T@IV$B83(LM<Y@``$J-?"`"_Q50EP``30'U28E%`$B%P'152(L%
M59@``$B-2P%*BQ0P#[8#B`*$P'0A/#UU#.L;9@\?1```A,!T$0^V`4B#P@%(
M@\$!B`(\/77KQ@(],<!F#Q]$```/MDP%`(A,`@%(@\`!A,EU[TB+1"0(9$@K
M!"4H````#X4/`0``2(/$&%M=05Q!74%>05_##Q]``#'`9@\?1```#[94!0!!
MB%0%`$B#P`&$TG7NZ[T/'T``3(L]N9<``$F#/P`/A+X```!,B?A%,>UF#Q^$
M``````!(@\`(1(GJ08/%`4B#.`!U[XUR`TAC]DC!Y@.+!;^G``"%P'5;QP6Q
MIP```0```$B)]_\54)8``$B%P`^$6/___TUC]4R)_DB)QTG!Y@-,B?+_%9&6
M``!(B05"EP``2(G!08U%`42);"0$2)A(QP3!`````.EX_O__#Q^``````$R)
M__\53Y8``$B)!1"7``!(B<%(A<`/A/W^__]-8_5)P>8#Z[P/'P`QP.EW_O__
MOA````!%,>WI7_____\5+I4``&9F+@\?A```````#Q\`2(/L"(L]II8``/\5
MH)4``(L]FI8``/\5E)4``$B+%;V4``!(C0V>=0``2(TU>#8``$B)Q_\5EI4`
M`(L]<)8``/\5:I4``$R-!>XW``!%,<E(C17I$@``2(G'3(G!2(TU838``$B#
MQ`C_)9*5``!FD$B#[`B+/3:6``#_%3"5``!(BQ59E```2(/$"$B-#39U``!(
MB<=(C34--@``_R4NE0``9F8N#Q^$```````/'P!!5%532('L("```&1(BP0E
M*````$B)A"08(```,<!(B>5,C:0D$!```/\5^9,``$R-#;\U``"Z`1```$B)
M[T&)P$B-#>(U``"^`0```#'`_Q6#E0``N@`0``!,B>9(B>__%;J3``!%,<"%
MP'@PC7@!2(G#2&/__Q6,E```28G`2(7`=!E(8]M,B>9(B<=(B=K_%5J4``#&
M!!@`28G`2(N$)!@@``!D2"L$)2@```!U#TB!Q"`@``!,B<!;74%<P_\5JY,`
M`&9F+@\?A```````Z2O___]F9BX/'X0``````$%7059!54%428GT54B)_4B-
M/4(U``!32('LR!```&1(BP0E*````$B)A"2X$```,<!(C70D'.@E^/__OB\`
M``!(B>](B</_%5R3``!(A<!T/S'`2(GN2(T]!#4``.B^^___2(GH2(N4)+@0
M``!D2"L4)2@````/A8,!``!(@<3($```6UU!7$%=05Y!7\-FD$B)[_\5[Y(`
M`$R)YTR-)<LT``!!B<;_%324``!,B>9(B<?_%?"3``!)B<5(A<!TD4&-1@%!
M@'T``$R--98U``")1"0,#X3&````9@\?1```2(7;=!1,B>Y(B=__%0>3``"%
MP`^$A0```$R)[_\5AI(``.L'#Q]``,8"`(G!@^@!2&/03`'J@#HO=.T#3"0,
M@?G_#P``#X\F____3(V\)+````!,B?%-B>@QP$B#[`BZ`!```+X!````3(G_
M54R-#1PT``#_%9Z3``!,B?](C70D,/\5.)(``%I9A<!U$(M$)#@E`/```#T`
M@```=%),B>8Q__\5'Y,``$F)Q4B%P`^$O/[__T&`?0``#X5`____2(7;=`6`
M.RYT%DR-+:4S``"Y`0```.E@____#Q]$``"`>P$`=+CKX@\?A```````O@$`
M``!,B?__%<*2``"%P'6<3(G^2(T]=3,``.@O^O__3(G__Q7FD@``Z6;^____
M%8N1``!F9BX/'X0```````^V!TF)^(3`=!=F#Q]$``!(@\<!/"\/M@=,#T3'
MA,!U[TR)P,-F9BX/'X0``````$B%_P^$QP```%6`/P!(B?T/A*(```#_%2R1
M``!(C50%_T@YU7(3Z9L````/'T0``$B#Z@%(.=5T)8`Z+W3R2#G5#X-_````
M2(/J`4@YU70.@#HO="A(@^H!2#G5=?*`?0`O=%1(C3W%,@``7?\E+I(``&8/
M'T0``(`Z+W4)2(/J`4@YU7+R2"GJ,<!(C4H"2('Y`!```'<92(/"`;D`$```
M2(GN2(T]E9(``/\5;Y$``%W##Q]$``!(C3U7,@``7?\EVI$``$@YU76RZY$/
M'P!(C3T_,@``_R7#D0``#Q\`05=!5D%505154TB-'4$R``!(@^Q(9@]O!1-Q
M``!D2(L$)2@```!(B40D.#'`,<!(C6PD#`\I1"009@]O!?]P``!FB40D,`\I
M1"0@#Q]$```QP$B)[DB)W^CC]/__2(7`=#9(8U0D#$B+!;*1``!(C0302(M0
M"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1V\,0``D#'`
M2(GN2(G?Z)/T__](A<!T-DAC5"0,2(L%8I$``$B-!-!(BU`(2(D02(72=-)F
MD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'70Q``"0,<!(B>Y(B=_H0_3_
M_TB%P'0V2&-4)`Q(BP42D0``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(
MB1!(A=)U\.N^9@\?1```2(T=+3$``)`QP$B)[DB)W^CS\___2(7`=#9(8U0D
M#$B+!<*0``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF
M#Q]$``!,C27D,```D#'`2(GN3(GGZ*/S__](A<!T-DAC5"0,2(L%<I```$B-
M!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-':0P
M``"0,<!(B>Y(B=_H4_/__TB%P'0V2&-4)`Q(BP4BD```2(T$T$B+4`A(B1!(
MA=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TM"3```)`QP$B)[DR)
M[^@#\___2(7`=#9(8U0D#$B+!=*/``!(C0302(M0"$B)$$B%TG329I!(BU`0
M2(/`"$B)$$B%TG7PZ[YF#Q]$``!,C3T0,```D#'`2(GN3(G_Z+/R__](A<!T
M-DAC5"0,2(L%@H\``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72
M=?#KOF8/'T0``$R--<HO``"0,<!(B>Y,B??H8_+__TB%P'0V2&-4)`Q(BP4R
MCP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```
M2(T=A"\``)`QP$B)[DB)W^@3\O__2(7`=#9(8U0D#$B+!>*.``!(C0302(M0
M"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1W2+@``D#'`
M2(GN2(G?Z,/Q__](A<!T-DAC5"0,2(L%DHX``$B-!-!(BU`(2(D02(72=-)F
MD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B)[DB-/>LN``#H>?'__TB)QDB%
MP'0*3(GW,<#H)_7__TB)[DB-/=LN```QP.A6\?__2(G&2(7`=`Y(C3W7+@``
M,<#H`/7__TB)[DB-/=$N```QP.@O\?__2(G&2(7`=#I,B>\QP.C=]/__,<!(
MC37;+@``3(GGZ,ST__](BT0D.&1(*P0E*````'552(/$2%M=05Q!74%>05_#
M2(GN2(T]CBX``#'`Z-SP__](B<9(A<!T#$R)_S'`Z(KT___KJTBX4$%27T-,
M14%(.40D(76:9H%\)"E./7612(UT)"OKT_\5T8L``)!(@^P89$B+!"4H````
M2(E$)`B+!3B-``"#^/]T&TB+5"0(9$@K%"4H````=4)(@\08PV8/'T0``$B-
M="0$2(T]JRT``#'`Z%7P__](B<(QP$B%TG02#[8"/#`/E<*$P`^5P`^VP"'0
MB07CC```ZZ[_%5N+``!F9BX/'X0``````$B#[`C_%4Z+``")Q_\5'HL``$B%
MP'0#2(L`2(/$",.0055!5$R-);XM``!52(G]3(GG4TB#[!AD2(L$)2@```!(
MB40D"#'`2(UT)`3HS^___TB%P'0(@#@`2(G#=3)(BT0D"&1(*P0E*`````^%
MN````$B)[DB#Q!A,B><QP%M=05Q!7>E7\___#Q^``````$B)[DB)Q_\5%(P`
M`$B%P'0?2(M$)`AD2"L$)2@```!U>4B#Q!A;74%<05W##Q]``$B)[_\5?XH`
M`$B)WTF)Q?\5<XH``$F-?`4"_Q4(BP``2(/L"$F)Z+X!````4TC'PO____](
MB<=)B<5,C0TM+```2(T-'BT``#'`_Q6HBP``6%I(BT0D"&1(*P0E*````'4(
M3(GNZ4O_____%2"*``!!5T%63(TUW2L``$%505154TB![(B!``!(B3PD2(UL
M)!Q,B?=(B>YD2(L$)2@```!(B80D>($``$B-!:<K``!(QT0D,`````!(QX0D
MB`````````!(QT0D4`````!(B40D*$B-!1`L``!(B40D:$B-!64L``!(B40D
M<$B-!14L``!(B40D>$B-!54L``!(B80D@````$B-!4HL``!(B40D2#'`Z$CN
M__](A<!T#(`X`$F)Q`^%OP0``/\5:8D``(G'_Q4YB0``2(7`#X0`!```3(LH
M387M#X3T`P``3(GO_Q4SB0``2(U\``'_%<B)``!%#[9%`$F)Q$6$P'1#38GG
M2(T=Z"L``&8/'X0``````$F#Q0%%#[;`3(G_2(G92,?"_____[X!````,<!)
M@\<"_Q52B@``10^V10!%A,!UT$B-7"1@2(T]-"L``.L39I!(BWL(2(/#"$B%
M_P^$/P$``$B)[C'`Z(7M__])B<5(A<!TW8`X`'382(G'Z,#O__^%P'3,3(GO
M_Q7CB0``28G`2(7`#X0'`0``#Q^``````$R)1"0(3(G'_Q5JB```3(GG2(G#
M_Q5>B```1(V\`P0$``!-8_],B?__%>J(``!!5$R-#2DJ``!(C0T6*P``28G%
M2(T%%2L``$C'PO____^^`0```%!,B>],BT0D&#'`_Q6#B0``3(GOOL`!``#_
M%;6'``!?05B#^/]U$_\5AX<``$2+"$&#^1$/A1@#``!(C;0DD````$R)[_\5
MJ8<``(G#A<`/A+<```!(BP0D38GHO@$```!%,>1(BSV1B0``2(T50BL``$B+
M"#'`_Q7OB```2(N$)'B!``!D2"L$)2@````/A:,%``!(@<2(@0``3(G@6UU!
M7$%=05Y!7\,/'P`QVTR-+2PJ``#K&0\?1```2&/#3(MLQ"!-A>UT.T&`?0``
M=#1,B>^#PP'H<>[__X7`=-U,B>__%92(``!)B<!(A<`/A;C^__](8\-,BVS$
M($V%[77(#Q\`13'`Z:#^__^+A"2H````)0#P```]`$````^%,O___T2+I"2L
M````_Q4#AP``03G$#X4;____2(L$)$B+`$B)1"0(BX0DJ````"7_`0``/<`!
M```/A?C^__],B?__%5Z'``!(B>Y(C3U@*0``28G$,<#H@NO__TB)QDB%P`^$
M/@(``$B+?"0(Z`SS__])B<=(A<`/A"@"``!,B?__%7^&``!(B<*#^`-^/TB8
M2(E4)`A(C353*0``28U\!_S_%<Z&``"%P'4B2(M4)`B#^@0/A*@#``"-0OM(
MF$&`/`<O#X28`P``#Q]``(L%NH<``(/X_P^$00,``$B-/4DH``"%P`^$T`$`
M`$B--;(H```QP$B-+2TI``#HG>[__TR-/0\I``#_%;B%``!52,?"_____TV)
MZ%!,C0W-)P``O@$```!,B>=(C0W9*```,<#_%3Z'``!86NM%9I#_%5*%``"#
M.!%U2_\5=X4``(/#`4B#[`A-B>A53(T-C2<``$R)^;X!````4TC'PO____],
MB>=0,<#_%?F&``!(@\0@OL`!``!,B>?_%2>%``"#^/]TJDR)[_\5\80``$R)
M]TR)YC'`Z/3M__],B>?H+/K__^FH_?__#Q^``````#';2(T]\"<``.L2#Q]$
M``!(8\-(BWS$0$B%_W0Y2(GN,<"#PP'H]NG__TB%P'3A@#@`=-Q(B<?_%6.&
M``!)B<5(A<`/A</[__](8\-(BWS$0$B%_W7'OPT```!,C2V<)P``_Q6`A0``
M0;A3````28G$Z;?[__](BP0D38GHO@$```!%,>1(BSV4A@``2(T5!2@``$B+
M"#'`_Q7RA0``Z?[\__\/'T0``$B)Q^AP^?__2(N$)'B!``!D2"L$)2@````/
MA90"``!(@<2(@0``3(GG6UU!7$%=05Y!7_\EOX4```\?@`````!(BP0D3(LX
MZ<S]___'!=*%````````3(G_,?8QP/\5-84``$B-/5TF``")Q87`#X02_O__
M2(V<)'`!``"Z`@```$C'QN[___^)Q_\54(4``+H&````2(G>B>__%6"$``"`
MO"1P`0```'4.@+PD<0$``$,/A)$!```QTC'VB>__%1R%```QP&?H_!L``$F)
MQ^L3#Q^``````$B)WDR)_V?H1!P``+H`@```2(G>B>__%0R$``")PH7`?]Z)
M[TB-K"0@`0``2(T=;"8``/\5SX,``$R)_DB)[V?HNQT``$B-A"1``0``2(E$
M)`A)B<=(C80D:`$``$B)!"0/'X``````1`^V10!,B?](B=F^`0```$C'PO__
M__\QP$B#Q0%)@\<"_Q6IA```3#D\)'732(T%3R8``,:$)&@!````4/]T)!!(
MC0T,)@``38GH3(GG,<"^`0```$R-#>PD``!(Q\+______Q5GA```65[I?OW_
M_P\?A```````2(T]""4``#'`2(GN2(D\).BKY___2(7`#X1V_O__#[8`A,`/
MA&O^__\\,`^$8_[__\<%-80```$```!(BSPDZ8K\__](BP0D2(M0"$B%T@^$
M6_S__TB)%"1(B=?_%8:"``!(@_@##X9$_/__2(L4)$B--6`E``!(C7P"_/\5
MUH(``$B+%"2%P$P/1/KI'_S__X"\)'(!``!!#X5A_O__@+PD<P$``$,/A5/^
M__^`O"1T`0``2`^%1?[__X"\)'4!``!%#X4W_O__N@(```!(Q\;&____B>__
M%4N#``"Z*0```$B)WHGO_Q5;@@``2(T%%R4``%!3Z<[^____%>^!``!F9BX/
M'X0```````\?0`!!54%454B#[!"+/6&#``!D2(L$)2@```!(B40D"#'`_Q5+
M@@``BSU%@P``2(G%_Q4\@@``#[:5L````$B-;"0$2(T]G",``$B)[HB0L0``
M`#'`Z%GF__](A<!T"8`X,0^$PP$``#'`Z`3Q__^+/?Z"``#_%?B!``"Y`P``
M`+H!````2(TU<20``$B)Q_\5OH$``$F)Q$B%P'0Z2(M`$(L]S((``$R+*/\5
MPX$``$B-%4@D``!(B<=,B>[_%4B!``!)BT0D$$R+($'V1"0.0`^%E`$``(L]
MEH(``/\5D($``+D#````N@$```!(C340)```2(G'_Q56@0``28G$2(7`=$!(
MC3VH(@``2(GN,<#HG>7__XL]5X(``$F)Q4F+1"00387M#X06`0``3(L@_Q4]
M@0``3(GJ2(G'3(GF_Q7&@```BSTH@@``_Q4B@0``N@$```!(C36I(P``2(G'
M_Q4=@0``BST'@@``28G$_Q7^@```3(GF2(T5G",``$B)Q_\5@X```(L]Y8$`
M`/\5WX```$B)[DB-/0TB``#&@+$`````,<#H!^7__TB)!2B2``!)B<1(A<!T
M0+[``0``3(GG_Q7"?P``C5`!@_H!=@F#^!$/A:X```!(BT0D"&1(*P0E*```
M``^%N````$B#Q!!=05Q!7<,/'P!(BSWAD0``Z+SU__](B07-D0``28G$2(7`
M=:5(C3VF(P``,<#_%6:```!F#Q]$``"`>`$`#X0Z_O__Z2[^__]F#Q^$````
M``!(BQ69D0``3(L@3(LJ_Q4=@```3(GG3(GNZ#+G___IW_[__P\?1```BST"
M@0``_Q7\?P``3(GF2(G'_Q4H@```Z4_^__^)P4B+!5*1``!,B>)(C3U0(P``
M2(LP,<#_%>5_``#_%3=_```/'X``````051)B?Q54TB#[!!D2(L$)2@```!(
MB40D"#'`Z,#M__\/MA!(B<6$TG089@\?1```2(/``8#Z+P^V$$@/1.B$TG7N
MBP5H@```387D#Y7#@_C_=&V%P`^5P"'#A-MU(DB+1"0(9$@K!"4H````#X6/
M````2(/$$%M=05S##Q]$``!!@#PD`'37N@0```!(C35Z(0``2(GO_Q4L?@``
MA<!UODB+1"0(9$@K!"4H````=5%(@\003(GG6UU!7.D0Y/__,<!(C70D!$B-
M/8$@``#H+>/__TB%P'0+#[8`A,!T!#PP=0_'!<-_````````Z6S____'!;1_
M```!````Z5G_____%2E^``!F#Q^$``````!!5TB)_DR-3SA!5D%505154TB!
M[)@"``!D2(L$)2@```!(B80DB`(``#'`2(GB3(V4)(````!)B=`/'X``````
M08L!28LY28/`$$F#P0@/R(G`2(GY28E`\$B)^$C!Z2!(P>@H2,'O."4`_P``
M2`GX2(G/2,'A"$C!YQB!X0``_P")_T@)^$@)R$F)0/A-.=!UKDB-N@`"```/
M'X``````2(M":$@S0D!(@\((2#-""$@S0OA(C0P`2,'H'T@)R(/@_TB)0GA(
M.?IUU4R+#DR+7A!(BWX@2(M>&$R)R$R)RDB+;@A(BTPD"$C!ZAM(P>`%2`G0
M`P0D2(V,"YEY@EJ-E#B9>8):3(G82#'82"'H2#'8C3P"2(GJ2(GH2,'H`DC!
MXAY)B?I("<),B=A)P>H;08G03#'`3"'(3#'82`'(2(GY2,'A!4P)T4R+5"00
M1(TD"$R)R$R)R4C!Z0)(P>`>3XV4$YEY@EI-B>5("<A)P>T;2#'"B<%((?I,
M,<),`=)-B>))P>(%30GJ3(ML)!A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9>8):
M2`GZ38G52#'0B==,(>!)P>T;2#'(3`'`38G02<'@!4T)Z$R+;"0@00'`3(G@
M2<'L`DC!X!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(`<I,
MB<%(P>$%3`GI3(ML)"@!T4R)TDG!Z@)(P>(>B<E*C;POF7F"6DP)TDF)S4@Q
MT$G![1M!B=),(<!,,>!(`?A(B<](P><%3`GO3(ML)#`!QTR)P$G!Z`)(P>`>
MB?]/C:0LF7F"6DP)P$F)_4@QPDG![1M!B<!((<I,,=),`>))B?Q)P>0%30GL
M3(ML)#A!`=1(B<I(P>D"2,'B'D6)Y$^-E"J9>8):2`G*38GE2#'02<'M&XG1
M2"'X3#'`3`'038GB2<'B!4T)ZDR+;"1`00'"2(GX2,'O`DC!X!Y%B=)/C80H
MF7F"6D@)^$V)U4@QPDG![1N)QTPAXD@QRDP!PDV)T$G!X`5-">A,BVPD2$$!
MT$R)XDG![`)(P>(>18G`2HV,*9EY@EI,">)-B<5(,=!)P>T;08G43"'02#'X
M2`'(3(G!2,'A!4P)Z4R+;"10`<%,B=!)P>H"2,'@'HG)2HV\+YEY@EI,"=!)
MB<U(,<))P>T;08G"3"'"3#'B2`'Z2(G/2,'G!4P)[TR+;"18`==,B<))P>@"
M2,'B'HG_3XVD+)EY@EI,"<))B?U(,=!)P>T;08G02"'(3#'03`'@28G\2<'D
M!4T)[$R+;"1@00'$2(G(2,'@'DC!Z0)%B>1/C90JF7F"6D@)R$V)Y4@QPDG!
M[1N)P4@A^DPQPDP!TDV)XDG!X@5-">I,BVPD:$$!TDB)^DC![P)(P>(>18G2
M3XV$*)EY@EI("?I-B=5(,=!)P>T;B==,(>!(,<A,`<!-B=!)P>`%30GH3(ML
M)'!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9>8):3`G@38G%2#'"2<'M&T&)Q$PA
MTD@Q^D@!RDR)P4C!X05,">E,BVPD>`'13(G22,'B'DG!Z@*)R4J-O"^9>8):
M3`G228G-2#'02<'M&T&)TDPAP$PQX$@!^$B)STC!YP5,">],BZPD@`````''
M3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]2#'"2<'M&T&)P$@ARDPQTDP!
MXDF)_$G!Y`5-">Q&C2PB2(G*2,'I`DR+I"2(````2,'B'D@)RD^-E"*9>8):
M38GL2#'02<'L&XG12"'X3#'`3`'038GJ2<'B!4T)XDR+I"20````00'"2(GX
M2,'@'DC![P)%B=)/C80@F7F"6D@)^$V)U$@QPDG![!N)QTPAZD@QRDP!PDV)
MT$G!X`5-">!%B<!,`<)-B>A)P>T"2<'@'D&)U$T)Z$R+K"28````3#'`3"'0
M2HV,*9EY@EI-B>5(,?A)P>T;2`'(3(GA2,'A!4P)Z8G)2`'(3(G12<'J`DC!
MX1Y!B<5,"=%-B<)%B<!),<I$,=),BY0DH````$J-O!>AZ]EN38GJ2`'73(GJ
M2<'J&TC!X@5,"=*)TD@!UTR)XDC!XAY)P>P"08GZ3`.$)*@```!,">))B<R)
MR4@#C"2P````23'41#'@38VD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$
M3(GH2<'M`DC!X!Y%B>!,">A)B=6)TD@#E"2X````23'%1#'O3(VL.:'KV6Y,
MB<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$DQ
MRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>
M18GB3`G"28G(2`.$),````")R4DQT$@#C"3(````13'H3HVL`*'KV6Y,B=!-
MB=!)P>@;2,'@!4P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"30
M````2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J
M`DC!X1Y$B>=,"=%)B<*)P$@#A"38````23'*13'J3HVL$J'KV6Y(B?I)B?I)
MP>H;2,'B!4P)THG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$@#C"3@
M````13'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$2(GX2,'O`DC!
MX!Y%B>!("?A(B=>)TD@#E"3H````2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;
M2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"3P````23'*
M13'B3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%
MB>),"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G038G02,'@!4G!Z!M(`XPD^```
M`$P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"0``0``2#''1#'G
M3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,
M"=%)B<*)P$@#A"0(`0``23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)
MTHG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$4QX$Z-I`"AZ]EN3(G0
M38G02<'H&TC!X`5,"<!(`XPD$`$``(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(
MB=>)TD@#E"08`0``2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)
M20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"0@`0``23'*13'B3HVD$J'K
MV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)
MR4DQT$4QZ$Z-K`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)^$C!X!Y(
MP>\"18GH2`.,)"@!``!("?A(B=>)TD@#E"0P`0``2#''1#'G38G$2(V,.:'K
MV6Y,B<=)P>P;2,'G!4P)YTV)U$G!Z@))P>0>B?]-"=1)B<)(`?F)P$TQXHG/
M2`.$)#@!``!%,>I)B?U.C902H>O9;DB)^DG![1M(P>(%3`GJ00'23(G"2<'H
M`DC!XAY%B=),"<)-B>!%B>1),=!)B=9!B=5$,<%-B=!(C8P(H>O9;DR)T$G!
MZ!M(P>`%3`G`1(T$`4B)^4C![P*XW+P;CTC!X1Y("?E)"<Z)ST@A^DTAUDD)
MUDB+E"1``0``2`'"3`'B38G$3`'R38G&2<'D!4G![AM-"?1!`=1,B=))P>H"
M2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+M"1(`0``20'&30'U38GF
M3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)
MSDTAYDPAPDP)\DR+M"10`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!
MUTR)XDG![`)(P>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0D6`$``$D!
MQDT!\DF)_DP!T4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),
M">E!B<U)"<Y)(?Y,(>I,"?),B[0D8`$``$D!QDT!\$V)UDP!PDV)T$G!X`5)
MP>X;30GP00'02(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+
MM"1H`0``20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"
M2,'A'D6)Y$P)T4&)RDD)SDTAQDPATDP)\DR+M"1P`0``20'&30'U38GF3`'J
M38GE2<'N&TG!Y05-"?5!`=5,B<)(P>(>2<'H`D6)[4P)PD@)T4F)UD&)T$TA
MUDPAX4P)\4R+M"1X`0``20'&3`'W38GN2`'Y3(GO2<'N&TC!YP5,"?=)B=8!
MSTR)X4G![`)(P>$>B?],">%!B<Q)"<Y-(>Y,(>),"?),B[0D@`$``$D!QDT!
M\DF)_DP!TDF)^DG![AM)P>(%30GR00'23(GJ2<'M`DC!XAY%B=),">I("=%)
MB=9!B=5((?E-(>9,"?%,B[0DB`$``$D!QDT!\$V)UDP!P4V)T$G![AM)P>`%
M30GP28G600'(2(GY2,'O`DC!X1Y%B<!("?F)STD)SDTAUD@A^DP)\DR+M"20
M`0``20'&30'T38G&3`'B38G$2<'N&TG!Y`5-"?1!`=1,B=))P>H"2,'B'D6)
MY$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+M"28`0``20'&30'U38GF3`'I38GE
M2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPA
MPDP)\DR+M"2@`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG!
M[`)(P>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0DJ`$``$D!QDT!\DF)
M_DP!T4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)
M"<Y)(?Y,(>I,"?),B[0DL`$``$D!QDT!\$V)UDP!PDV)T$G![AM)P>`%30GP
M00'02(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"2X`0``
M20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)
MY$P)T4D)SD&)RDTAQDPATDP)\DR+M"3``0``20'&30'U38GF3`'J38GE2<'N
M&TG!Y05-"?5!`=5,B<))P>@"2,'B'D6)[4P)PD@)T4F)T$&)UTTAT$PAX4P)
MP4R+A"3(`0``20'`3`''38GH2`'Y3(GO2<'H&TC!YP5,"<=$C00Y3(GG2<'L
M`DB)T4C!YQY,">=!B?Q("?E,(>E,(>)("<I(BXPDT`$``$@!P4P!T4V)PD@#
MA"38`0``2`'*3(G!2<'J&TC!X05,"=&)R4@!RDR)Z4G![0)(P>$>08G23`GI
M2`G/28G-08G.3"''32'E20G]2HT\.$R)T$R+O"3X`0``3`'O38G52,'@!4G!
M[1M,">B)P$@!QTR)P$G!Z`)(P>`>08G]20G`N-;!8LI,,<$QT4B+E"3@`0``
M2`'"3`'B38GL2`'*3(GI2<'L&TC!X05,">%-B=2)R4G!Y!Y(`<I)P>H"20''
M30GB38G$B=%%B<!-,=1$,>=,BZ0DZ`$``$D!Q$T!]$F)SDP!YTF)S$G![AM)
MP>0%30GT38GN2<'M`DG!YAY%B>1-"?5,B[0D\`$``$P!YT&)_$D!QDT!\$V)
MUDTQ[D0Q\DV)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!(B<I(P>D"2,'B'D6)
MQD@)RD2)T4V)ZDDQTDP!^4R+O"0``@``1#'738GR2`'/3(GQ2,'A!4G!ZAM)
M`<=,"=&)R4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD
M$`(``$4QZ$V)U4D!R$R)T4G![1M)`<=(P>$%3`GIB<E)`<A,B?%)P>X"2,'A
M'D6)Q4P)\4R+M"0(`@``20'&3`'R38GF23'.1#'W38GN2`'73(GJ2<'N&TC!
MX@5,"?*)TD@!UTR)TDG!Z@)(P>(>08G^20G21(GB28G,B<E,`?I-,=1,B[PD
M(`(``$4QX$V)]$D!T$R)\DG![!M)`<=(P>(%3`GBB=))`=!,B>I)P>T"2,'B
M'D6)Q$P)ZDR+K"08`@``20'%3`'I38G523'51#'O38GE2`'/3(GA2<'M&TC!
MX05,">F)R4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD
M,`(``$4QT$V)ZDD!R$R)Z4G!ZAM(P>$%3`G1B<E)`<A,B>%(P>$>2<'L`D6)
MPDD!QTP)X4R+I"0H`@``20'$3`'B38GT23',1#'G38G42`'73(G22<'L&TC!
MX@5,">*)TD@!UTR)ZDG![0)(P>(>08G\20G51(GR28G.B<E-,>Y,`?I,B[PD
M0`(``$4Q\$V)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!,B=))P>H"2,'B'D6)
MQDP)TDR+E"0X`@``20'"3`'138GJ23'21#'738GR2`'/3(GQ2,'A!4G!ZAM)
M`<=,"=&)R4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD
M8`(``$4QZ$V)U4D!R$R)T4G![1M(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)
MQ4P)\4R+M"1(`@``20'&3`'R38GF18GD23'.1#'W38GN2`'73(GJ2<'N&TC!
MX@5,"?*)TD@!UTR)TDG!Z@)(P>(>08G^20G22(N4)%`"``!(`<))`=1(B<J)
MR4PQTDD!QT0QPDV)\$D!U$R)\DG!Z!M(P>(%3`G"B=))`=1,B>I)P>T"2,'B
M'D6)X$P)ZDR+K"18`@``20'%3`'I38G523'51#'O38G%2`'/3(G!2<'M&TC!
MX05,">F)R4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD
M<`(``$4QXDV)[$P!T4V)ZDG![!M)P>(%30GB38G$18G22<'D'DP!T4G!Z`))
M`<=-">!,BZ0D:`(``$&)RDD!Q$@#A"1X`@``3`'B38GT3`'(33'$1#'G38G4
M2`'73(G22<'L&TC!X@5,">)-B>Q)P>T"2<'D'HG230GE18GT38G&2`'733'N
MB?I-`?Q%B<!$,?%)B=9,`<!-B>A,`>%)B=1)P>X;2<'D!4T)]$0!X4V)U$G!
MZ@))P>0>B<E-">)-,=!$,<=)B<A(`?A(B<](P><%2<'H&P'I00':3`G'1`-N
M($B)3@@!^$R)5AA(B09(B=!(P>H"2,'@'DR);B!("=!$`=A(B4802(N$)(@"
M``!D2"L$)2@```!U$DB!Q)@"``!;74%<05U!7D%?P_\5[V<``&9F+@\?A```
M````#Q]``$B#[`B_@````/\5:6@``+J)J\WON?[<NIB^\.'2PTC'``$C16=(
MB5`(2(E($$C'0!AV5#(02(EP($C'0"@`````2,=`,`````#'0'@`````2(/$
M",-F9BX/'X0``````$%72&/"059)B<9!54%428G\54B-;SA32(GS2(/L"$B+
M=RA(BU<PC0S&2#GQ2(E/*$B#T@!(P>@=2`'02(E',$AC1WB%P`^%[0```$&#
M_C\/CC,!``!!@^Y`18GW0<'O!D6-;P%)P>4&20'=#Q]$``#S#V\#3(GG2(/#
M0`\110#S#V]+T`\131#S#V]3X`\152#S#V];\`\173#HP>C__TPYZW7,0<'G
M!D4I_DECQDB#^`AR7$F+50!(C4T(2(/A^$F)5"0X28M4!?A(B50%^$@IS4@!
MZ$DI[4B#X/A(@_@(<AA(@^#X,=))BW05`$B)-!%(@\((2#G"<NY%B70D>$B#
MQ`A;74%<05U!7D%?PV:0J`1U?$B%P'3A00^V50!!B%0D.*@"=--!#[=4!?YF
MB50%_NO&#Q]``$&]0````$B-?`4`2(G>02G%13GU10]/[DUC_4R)^O\5I&8`
M`$&+1"1X1`'H08E$)'B#^$!UD4R)YT4I[DP!^^CDY___Z<K^__\/'X``````
M28G=Z1O___]!BU4`08E4)#A!BU0%_(E4!?SI4____V8/'X0``````$%63(UV
M.$%505152(GU4TB+1BA(B?M$BV8H1(MN,$C!Z`.#X#]!#\Q!#\V-2`%(F,9$
M!CB`2&/!3`'P@_DX#XX4`0``OD`````ISG0/,=*)T8/"`<8$"``Y\G+S2(GO
MZ$SG__]F#^_`#Q%%.$G'1C``````00\11A!!#Q%&($2);7!(B>]$B65TZ"+G
M__](BT4`2(GO2,'H&(@#2(M%`$C!Z!"(0P%(BT4`B&,"2(M%`(A#`TB+10A(
MP>@8B$,$2(M%"$C!Z!"(0P5(BT4(B&,&2(M%"(A#!TB+11!(P>@8B$,(2(M%
M$$C!Z!"(0PE(BT40B&,*2(M%$(A#"TB+11A(P>@8B$,,2(M%&$C!Z!"(0PU(
MBT48B&,.2(M%&(A##TB+12!(P>@8B$,02(M%($C!Z!"(0Q%(BT4@B&,22(M%
M((A#$UM=05Q!74%>_R7^8P``9@\?1```NC@````Q_RG*@_H(<DJ)T4C'````
M``!(QT0(^`````!(C4@(2(/A^$@IR`'"@^+X@_H(#X+M_O__@^+X,<")QH/`
M"$B)/#$YT'+SZ=;^__\/'X0``````/;"!'4CA=(/A,'^___&``#VP@(/A+7^
M__\QR6:)3!#^Z:G^__\/'P#'``````#'1!#\`````.F3_O__#Q]$``#S#Q[Z
M05=,C3T#80``059)B=9!54F)]4%408G\54B-+?1@``!33"G]2(/L".@?Q?__
M2,']`W0?,=L/'X``````3(GR3(GN1(GG0?\4WTB#PP%(.=UUZDB#Q`A;74%<
M05U!7D%?PV9F+@\?A```````\P\>^L-F+@\?A```````D/,/'OI(BPW-9```
MZ?#$___S#Q[Z2(/L"$B#Q`C#````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0
M051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R
M>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K
M97(Z.E9%4E-)3TX`,2XP-30`+64`+2T``````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@
M)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@
M)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE
M;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["B1005)?34%'24,@/2`B
M7&Y005(N<&U<;B(["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R
M7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI-04=)0SH@
M>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N
M(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A
M9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE
M<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D
M8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M
M<R!?1D@["FUY("1M86=I8U]P;W,@/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK
M7W-I>F4[(",@3D]413H@)&UA9VEC7W!O<R!I<R!A(&UU;'1I<&QE(&]F("1C
M:'5N:U]S:7IE"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L
M("1M86=I8U]P;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K
M(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F
M+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T
M.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*:68@*"1M86=I8U]P
M;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B10
M05)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*
M?0IS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F
M+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI
M<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&
M24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q
M6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@
M)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M
M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L
M("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U
M;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD
M24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T
M(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^
M<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M
M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F
M:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H
M.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D
M=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"G5N;&5S<R`H)&)U9B!E<2`B4$M<,#`S7#`P-"(I('L*
M;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@
M;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P87(B73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D
M("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL
M95T@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*
M0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O
M=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A
M7W!O<RD@>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD
M:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;
M)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B
M7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD
M;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G
M('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP
M<FEN="@D;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\
M?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@
M("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N
M86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*
M?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^
M(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO
M*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT
M(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ
M<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O
M(#T@=6YD968["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X[
M"F-L;W-E("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O
M;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA
M;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H
M,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E
M<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*
M)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD
M;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D
M;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z
M:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A
M)$5.5GM005)?1$5"54=].PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U
M=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92)=*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L
M("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@
M)"%=.PIS965K("1F:"P@+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U
M9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L
M(#(["G)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M
M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92!["FUY
M("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T
M>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH
M97AD:6=E<W0["GT@?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L
M:6U]8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.
M5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?71E
M;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B
M(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?
M.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M
M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"([
M"F]P96X@;7D@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A
M;B=T('=R:71E("(D=&5M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N
M=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I
M;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N
M;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD
M<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D
M+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D
M<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P
M<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R
M;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#
M=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H
M)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]
M7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%
M3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$
M14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@
M)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%
M04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI
M('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H
M*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^
M("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF
M("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]
M"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U
M:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@
M)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH```!P97)L>'-I+F,`
M``````````````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(`$;`SOT````'0```+"`__\H`0``T(#__]0%``#P@O__$`$``/"#__]0`0``
MP(3__YP!``!`AO__X`$``-"&__\$`@``L(?__T`"````BO__C`(``'"*__^D
M`@``L(K__[P"``"`B___\`(``)"+__\$`P``H(W__V0#``#0C?__>`,``+".
M__^H`P``4)/___@#``#0D___%`0``/"3__\L!````)7__X@$``!`G?__7`4`
M`/"?__^0!0```*'__P`&``!`M___4`8``*"W__]H!@``4+G__[0&``!`N___
M^`8``+"[__]`!P``P+O__U@'````````%``````````!>E(``7@0`1L,!PB0
M`0``%````!P```#8@?__+P````!$!Q``````)````#0```"`?___(``````.
M$$8.&$H/"W<(@``_&CLJ,R0B`````$@```!<````F(+__\T`````0@X0CP)"
M#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y``FT*#CA$#C!!#BA"#B!"#AA"
M#A!"#@A("P!`````J````!R#__]]`0```$(.$(X"0@X8C0-"#B",!$$.*(8%
M00XP@P9'#M`!?@H.,$$.*$$.($(.&$(.$$(."$L+`"````#L````6(3__X0`
M````00X0A@)*#K`!`G$*#A!!#@A!"S@````0`0``Q(3__]X`````0@X0C@)'
M#AB-`T(.((P$1`XHA@51#L`@`J4*#BA!#B!"#AA"#A!"#@A$"T@```!,`0``
M:(7__T("````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1PY0`QT!
M"@XX00XP00XH0@X@0@X80@X00@X(10L4````F`$``&R'__]N`````$0.$`)D
M#@@4````L`$``,2'__\R`````$0.$%<."``P````R`$``.R'___%`````$(.
M$(P"00X8A@-!#B"#!$<.P$`"K`H.($0.&$$.$$(."$$+$````/P!``"(B/__
M!0````````!<````$`(``(2(__\%`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%
M1`XPA@9+#CB#!T<.@"("90H..$$.,$$.*$(.($(.&$(.$$(."$,+`J\.B").
M#I`B7`Z((D$.@"(````0````<`(``#2*__\E`````````"P```"$`@``4(K_
M_]T`````2@X0A@("8@K&#@A,"WH*#@A&"T@*Q@X(1@M*#@C&`$P```"T`@``
M`(O__Y\$````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'2PZ``0,S
M!`H..$$.,$$.*$(.($(.&$(.$$(."$$+````&`````0#``!0C___=0````!$
M#B!M"@X(1PL``!0````@`P``M(___Q\`````1`X06@X(`%@````X`P``O(__
M_Q`!````0@X0C0)"#AB,`T@.((8$1PXH@P5$#D`"0@H.*$8.($$.&$(.$$(.
M"$P+90H.*$$.($$.&$(.$$(."$4+9`Y(20Y09`Y(00Y`````T````)0#``!P
MD/__,0@```!"#A"/`D(.&(X#20X@C01"#BB,!4$.,(8&00XX@P='#L"#`@.X
M`0[(@P)E#M"#`E\.R(,"0@[`@P(">0H..$0.,$$.*$(.($(.&$(.$$(."$0+
M`X$!#LB#`DL.T(,"7P[(@P)!#L"#`EP.R(,"1`[0@P)0#MB#`DL.X(,"3`[`
M@P(#"P$*#CA$#C!!#BA"#B!"#AA"#A!"#@A-"P,]`0[(@P)$#M"#`FD.R(,"
M00[`@P(#`@$*#LB#`D$.T(,"10L````P````:`0``-R7__^I`@```$(.$(T"
M0@X8C`-!#B"&!$0.,`/F`0H.($$.&$(.$$(."$0+0````)P$``!8FO__!P$`
M``!"#A",`D0.&(8#00X@@P1$#C`":PH.($$.&$$.$$(."$8+=`H.($0.&$$.
M$$(."$4+```H````X`0``/1Z__\6`@```$(.$(P"00X8A@-$#E`#J`$*#AA$
M#A!"#@A!"TP````,!0``^)K__S$6````0@X0CP))#AB.`T(.((T$0@XHC`5!
M#C"&!D$..(,'1P[0!0,(%@H..$$.,$$.*$(.($(.&$(.$$(."$$+````%```
M`%P%``#HL/__50````!$#A`"4`X(2````'0%```PL?__IP$```!"#A"/`D4.
M&(X#10X@C01"#BB,!40.,(8&10XX@P='#D`"Y0H..$$.,$$.*$(.($(.&$(.
M$$(."$,+`$````#`!0``E++__^L!````0@X0C@)&#AB-`T(.((P$00XHA@5$
M#C"#!@,V`0H.*$$.($(.&$(.$$(."$P+````````1`````0&``!`M/__90``
M``!&#A"/`DD.&(X#10X@C01%#BB,!40.,(8&2`XX@P='#D!N#CA!#C!!#BA"
M#B!"#AA"#A!"#@@`%````$P&``!HM/__!0``````````````$````&0&``!@
MM/__$```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````4",`````````(P````````$`````````Y0(````````!`````````/`"
M`````````0```````````P````````\`````````E@0````````,````````
M```@````````#0````````!`6P```````!D`````````P+L````````;````
M``````@`````````&@````````#(NP```````!P`````````"`````````#U
M_O]O`````,`#````````!0````````"`#@````````8`````````:`4`````
M```*`````````+D$````````"P`````````8`````````!4`````````````
M```````#`````````/"]`````````@`````````8`````````!0`````````
M!P`````````7`````````"`;````````!P````````"0%`````````@`````
M````D`8````````)`````````!@`````````&````````````````````/O_
M_V\``````0``"`````#^__]O```````4````````____;P`````"````````
M`/#__V\`````.A,```````#Y__]O``````0`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#0NP``````````````````````````
M```V(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#@8@```````$=#
M0SH@*$=.52D@,3$N,2XP```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N
M<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S
M:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```
M````````````````````````````````````````````````````````````
M``````````````````````````L````!`````@`````````8`P```````!@#
M````````'`````````````````````$````````````````````3````!P``
M``(`````````.`,````````X`P```````$`````````````````````(````
M````````````````)@````<````"`````````'@#````````>`,````````D
M````````````````````!````````````````````#D````'`````@``````
M``"<`P```````)P#````````(`````````````````````0`````````````
M``````!'````]O__;P(`````````P`,```````#``P```````*@!````````
M!@`````````(````````````````````40````L````"`````````&@%````
M````:`4````````8"0````````<````!````"``````````8`````````%D`
M```#`````@````````"`#@```````(`.````````N00`````````````````
M``$```````````````````!A````____;P(`````````.A,````````Z$P``
M`````,(`````````!@`````````"``````````(`````````;@```/[__V\"
M```````````4`````````!0```````"0``````````<````"````"```````
M`````````````'T````$`````@````````"0%````````)`4````````D`8`
M```````&``````````@`````````&`````````"'````!````$(`````````
M(!L````````@&P```````!@`````````!@```!8````(`````````!@`````
M````D0````$````&```````````@`````````"`````````;````````````
M````````!````````````````````(P````!````!@`````````@(```````
M`"`@````````(````````````````````!``````````$`````````"7````
M`0````8`````````0"````````!`(``````````[```````````````````0
M````````````````````G0````$````&`````````$!;````````0%L`````
M```-````````````````````!````````````````````*,````!`````@``
M````````8`````````!@````````<#\``````````````````!``````````
M``````````"K`````0````(`````````<)\```````!PGP```````/0`````
M```````````````$````````````````````N0````$````"`````````&B@
M````````:*````````!X!@``````````````````"```````````````````
M`,,````.`````P````````#`NP```````,"K````````"```````````````
M``````@`````````"`````````#/````#P````,`````````R+L```````#(
MJP````````@````````````````````(``````````@`````````VP````8`
M```#`````````-"[````````T*L````````@`@````````<`````````"```
M```````0`````````.0````!`````P````````#PO0```````/"M````````
M$`(```````````````````@`````````"`````````#I`````0````,`````
M`````,``````````L````````"`````````````````````(````````````
M````````[P````@````#`````````"#`````````(+````````"`$```````
M````````````(````````````````````/0````!````,```````````````
M`````""P````````$@````````````````````$``````````0`````````!
M`````P`````````````````````````RL````````/T`````````````````
2```!````````````````````
